==> haskell-binary-conduit-1.3.1-256-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-conduit
version:              1.3.1
visibility:           public
id:                   binary-conduit-1.3.1-ElBXbEM7C9zKRQwCkx2la9
key:                  binary-conduit-1.3.1-ElBXbEM7C9zKRQwCkx2la9
license:              MIT
copyright:            2013 Alexander Vershilov
maintainer:           alexander.vershilov@gmail.com
author:               Alexander Vershilov
stability:            Experimental
homepage:             http://github.com/qnikst/binary-conduit/
synopsis:             data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.

category:             Conduit
abi:                  c56cce677e400c47e6087f084a6df32e
exposed:              True
exposed-modules:      Data.Conduit.Serialization.Binary
import-dirs:          /usr/lib/ghc-9.0.1/site-local/binary-conduit-1.3.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/binary-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/binary-conduit-1.3.1
hs-libraries:         HSbinary-conduit-1.3.1-ElBXbEM7C9zKRQwCkx2la9
depends:
    base-4.15.0.0 binary-0.8.8.0 bytestring-0.10.12.1
    conduit-1.3.4.2-G1HkDA3DXNW8qvzQqLFdeJ exceptions-0.10.4
    vector-0.12.3.1-HMAplmdcuCN6dtD8e6QGwL

haddock-interfaces:
    /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock

haddock-html:         /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-conduit-1.3.1-344-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-conduit
version:              1.3.1
visibility:           public
id:                   binary-conduit-1.3.1-GkW9Ee3nqv1ETl2LEFYHyH
key:                  binary-conduit-1.3.1-GkW9Ee3nqv1ETl2LEFYHyH
license:              MIT
copyright:            2013 Alexander Vershilov
maintainer:           alexander.vershilov@gmail.com
author:               Alexander Vershilov
stability:            Experimental
homepage:             http://github.com/qnikst/binary-conduit/
synopsis:             data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.

category:             Conduit
abi:                  27d60ccb8e9e78aa571a6f7c485ee201
exposed:              True
exposed-modules:      Data.Conduit.Serialization.Binary
import-dirs:          /usr/lib/ghc-9.0.2/site-local/binary-conduit-1.3.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/binary-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-conduit
hs-libraries:         HSbinary-conduit-1.3.1-GkW9Ee3nqv1ETl2LEFYHyH
depends:
    base-4.15.1.0 binary-0.8.8.0 bytestring-0.10.12.1
    conduit-1.3.4.3-8itn5Qj41ZSLgRSjBhzqyF exceptions-0.10.4
    vector-0.13.0.0-80dNWv5W93FGfZf7Ao5mAf

haddock-interfaces:
    /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock

haddock-html:         /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
